[![Build Status](https://travis-ci.org/xiachufang/cnregion.svg)](https://travis-ci.org/xiachufang/cnregion)

# cnregion

Utils for Administrative divisions of China


## Api

```python

In [1]: import cnregion

In [2]: print cnregion.get_region('156110101001000')
<Region 110101001000/东华门街道>
```
